@@ -1,7 +1,8 @@
+import zipfile
 from os import walk
 from os.path import join
-import zipfile
-from metapack.util import slugify
+
+from metatab.util import slugify
 
 from .core import PackageBuilder
 
@@ -12,7 +13,7 @@ class ZipPackageBuilder(PackageBuilder):
     type_code = 'zip'
     type_suffix = '.zip'
 
-    def __init__(self, source_ref=None, package_root=None,  callback=None, env=None):
+    def __init__(self, source_ref=None, package_root=None, callback=None, env=None):
 
         super().__init__(source_ref, package_root, callback, env)
 
@@ -41,11 +42,11 @@ class ZipPackageBuilder(PackageBuilder):
         for root, dirs, files in walk(self.source_dir):
             for f in files:
                 source = join(root, f)
-                rel = source.replace(self.source_dir,'').strip('/')
+                rel = source.replace(self.source_dir, '').strip('/')
                 dest = join(root_dir, rel)
 
-                self.zf.write(source,dest)
+                self.zf.write(source, dest)
 
         self.zf.close()
 
-        return self.package_path
\ No newline at end of file
+        return self.package_path
